#
# spec file for package notmuch
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           notmuch
Version:        0.22.1
Release:        3.17
Summary:        The mail indexer
License:        GPL-3.0+
Group:          Productivity/Networking/Email/Utilities
Url:            http://notmuchmail.org
Source0:        http://notmuchmail.org/releases/%{name}-%{version}.tar.gz
Source1:        http://notmuchmail.org/releases/%{name}-%{version}.tar.gz.sha1
Source2:        http://notmuchmail.org/releases/%{name}-%{version}.tar.gz.sha1.asc
Source3:        notmuch.keyring

%{bcond_without python}
%{bcond_without python3}
%{bcond_without emacs}

#FIXME: at they are not enabled
%{bcond_with ruby}
%{bcond_with go}

%define libversion 4

BuildRequires:  libxapian-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(gmime-2.6)
BuildRequires:  pkgconfig(talloc)

%if %{with emacs}
BuildRequires:  emacs-el
BuildRequires:  emacs-nox
%endif
%if %{with python}
BuildRequires:  python-Sphinx
BuildRequires:  python-devel
%endif
%if %{with python3}
BuildRequires:  python3-devel
%endif
%if %{with ruby}
BuildRequires:  ruby-devel
%endif
%if %{with go}
BuildRequires:  go
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Because dealing with your mail can be so much better.

"Not much mail" is what Notmuch thinks about your email collection. Even if
you receive 12000 messages per month or have on the order of millions of
messages that you've been saving for decades. Regardless, Notmuch will be
able to quickly search all of it. It's just plain not much mail.

"Not much mail" is also what you should have in your inbox at any time.
Notmuch gives you what you need, (tags and fast search), so that you can
keep your inbox tamed and focus on what really matters in your life, (which
is surely not email).

Notmuch is an answer to Sup. Sup is a very good email program written by
William Morgan (and others) and is the direct inspiration for Notmuch.
Notmuch began as an effort to rewrite performance-critical pieces of Sup in
C rather than ruby. From there, it grew into a separate project. One
significant contribution Notmuch makes compared to Sup is the separation of
the indexer/searcher from the user interface. (Notmuch provides a library
interface so that its indexing/searching/tagging features can be integrated
into any email program.)

Notmuch is not much of an email program. It doesn't receive messages (no
POP or IMAP support). It doesn't send messages (no mail composer, no
network code at all). And for what it does do (email search) that work is
provided by an external library, Xapian. So if Notmuch provides no user
interface and Xapian does all the heavy lifting, then what's left here? Not
much.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libnotmuch%{libversion} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n libnotmuch%{libversion}
Summary:        A shared library for %{name}
Group:          Productivity/Networking/Email/Utilities

%description -n libnotmuch%{libversion}
The libnotmuch3 package contains shared libraries for %{name}.

%if %{with python}
%package -n python-%{name}
Summary:        Python bindings for %{name}
Group:          Development/Libraries/Python
#py_requires is useless as it was not designed for sub-packages
#BR: python-devel is on the top of spec file
Requires:       python = %{py_ver}
Recommends:     python-%{name}-doc = %{version}

%description -n python-%{name}
Python interface (bindings) for %{name}

%package -n python-%{name}-doc
Summary:        Documentation of Python bindings for %{name}
Group:          Documentation/HTML

%description -n python-%{name}-doc
Documentation of Python interface (bindings) for %{name}
%endif

%if %{with python3}
%package -n python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Libraries/Python
Requires:       python = %{py3_ver}
%if %{with python}
#documentation is built only when python2 is installed
#this shall be fixed once python2 disappear from openSUSE
Recommends:     python-%{name}-doc = %{version}
%endif

%description -n python3-%{name}
Python3 interface (bindings) for %{name}
%endif

%if %{with emacs}
%package emacs
Summary:        Emacs lisp email client based on %{name}
Group:          Productivity/Networking/Email/Utilities
Requires:       %{name} = %{version}-%{release}
Requires:       emacs
Requires:       emacs-el

%description emacs
%{name}-based email client written in emacs lisp
%endif

%prep
%setup -q

%build
#hand-made configure script
#zsh completion is a part of zsh itself
export CFLAGS="%{optflags}"
./configure \
%if %{without emacs}
  --without-emacs \
%endif
  --without-zsh-completion \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --includedir=%{_includedir} \
  --mandir=%{_mandir} \
  --sysconfdir=%{_sysconfdir}

#XXX: failed to build with smp_flags
#make %{?_smp_mflags}
make

#TODO: bindings - go, ruby
pushd bindings

%if %{with python3}
cp -r python python3
pushd python3
python3 setup.py build
popd
%endif

%if %{with python}
pushd python
python2 setup.py build
pushd docs
make dirhtml
rm -f build/dirhtml/.buildinfo
popd
popd
%endif

popd

%install
%make_install

%if %{with python3}
pushd bindings/python3
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd
%endif

%if %{with python}
pushd bindings/python
python2 setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd
%endif

%post -n libnotmuch%{libversion} -p /sbin/ldconfig
%postun -n libnotmuch%{libversion} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING-GPL-3 NEWS README
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}-hooks.5*
%{_mandir}/man7/%{name}-search-terms.7*

%files -n libnotmuch%{libversion}
%defattr(-,root,root)
%{_libdir}/libnotmuch.so.%{libversion}*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}.h
%{_libdir}/libnotmuch.so

%if %{with python}
%files -n python-%{name}
%defattr(-,root,root)
%doc bindings/python/README
%{python_sitelib}/%{name}/
%{python_sitelib}/%{name}*egg-info

%files -n python-%{name}-doc
%defattr(-,root,root)
%doc bindings/python/docs/build/dirhtml/
%endif

%if %{with python3}
%files -n python3-%{name}
%defattr(-,root,root)
%doc bindings/python/README
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}*egg-info
%endif

%if %{with emacs}
%files emacs
%defattr(-,root,root)
%{_datadir}/emacs/site-lisp/
%endif

%changelog
* Thu Aug 25 2016 mimi.vx@gmail.com
- version 0.22.1
  - Correct the definition of LIBNOTMUCH_CHECK_VERSION.
  - Document the (lack of) operations permitted on a closed database.
  - Fix race condition in dump / restore tests.
  - Notmuch-mutt: Use env to locate perl.
  - Emacs: Tell message-mode mode that outgoing messages are mail
  - Emacs: This makes message-mode configuration behave more predictably.
  - Respect charset of MIME parts when reading them
  - Fix previous assumption that everyone uses UTF-8.
* Sat Jun 18 2016 lmb@suse.com
- version 0.22
  - Xapian 1.3 support
  - Limited support for S/MIME messages
  - Fix for threading bug involving deleting and re-adding messages.
  - Fix for case-sensitive content disposition headers.
  - Fix handling of 1 character directory names at top level.
  - Emacs: Notmuch replies now include all parts shown in the show view
  - Emacs: Filtering or Limiting messages is now bound to `l` in the
    search view
  - Emacs: `F` forwards all open messages in a thread
  - Emacs: Preferred content type can be determined from the message
    content
- version 0.21
  - Notmuch now requires gmime >= 2.6.7. The gmime 2.4 series is no
    longer supported.
  - Database revision tracking: `lastmod:` queries
  - Date queries now support `date:<expr>..!` shorthand for
    `date:<expr>..<expr>`
  - Notmuch database upgrade to support `lastmod:` queries
  - The `notmuch address` command supports new deduplication schemes
* Wed Jul  8 2015 dsterba@suse.cz
- version 0.20.2
  - Emacs: Bug fix for marking messages read in notmuch-tree mode
- version 0.20.1
  - test suite fixes
- version 0.20
  - There is a new mimetype: search prefix
  - Path to gpg is now configurable
  - Notmuch-Mutt: Support messages without Message-IDs.
  - Undeprecate single message mboxes
  - Contrib: notmuch-deliver is removed
  - Improved notmuch-search-terms.7
* Wed Feb  4 2015 mvyskocil@opensuse.org
- workaround a source checker issue by moving bcond macros behind
  Name and Version tag
* Thu Jan 29 2015 dsterba@suse.cz
- readd the signature file and update keyring
* Thu Jan 29 2015 dsterba@suse.cz
- spec updates
  - remove gpg checks (broken) and the related files
  - define lib version
- version 0.19
  - Stopped notmuch dump failing if someone writes to the database
  - notmuch insert requires succesful message indexing for success status
  - notmuch insert has gained support for post-insert hook
  - notmuch deliver is deprecated
  - notmuch search now supports --duplicate=N option with --output=messages
  - Added notmuch address subcommand
- versions 0.18.1, 0.18.2
  - This is a bug fix and portability release
  - Resurrect support for single-message mbox files
- version 0.18
  - The folder: search prefix now requires an exact match
  - There is a new path: search prefix
  - Notmuch database upgrade due to folder: and path: changes
  - Support for indexing mbox files has been dropped
  - notmuch dump now defaults to batch-tag format
  - notmuch new has a --quiet option
  - notmuch insert respects maildir.synchronize_flags config option
- version 0.17
  - Incompatible change in SHA1 computation
  - New options to better support handling duplicate messages
  - Improved notmuch new performance for unchanged folders
  - notmuch reply --format=text RFC 2047-encodes headers
  - notmuch compact command
  - emacs interface:
  - notmuch-tree (formerly notmuch-pick) has been added to mainline
  - The notmuch-tag function now requires a list of tag changes
  - Fixed notmuch-reply putting reply in primary selection
  - Fixed notmuch-mua-reply point placement when signature involved
- version 0.16
  - Support for delivering messages to Maildir
  - notmuch count --batch option
  - notmuch tag option to remove all tags from matching messages
  - Decrypting commands explicitly expect a gpg-agent
  - Bash command-line completion
  - many emacs interface updates
* Mon Feb 18 2013 mvyskocil@suse.com
- remove zsh completion, it's part of zsh itself
* Mon Feb 18 2013 mvyskocil@suse.com
- drop contrib from installed files
- install zsh to correct location
- instal notmuch.el as notmuch-emacs package like Debian do
* Mon Feb 18 2013 mvyskocil@suse.com
- initial packaging of notmuch 0.15.2 for SUSE
  * including python/python3 bindings
  * and notmuchmail (the original emacs lisp based
    email client for notmuch library)
